@@ -1164,6 +1164,26 @@ gst_pad_probe_type_get_type (void)
         "GST_PAD_PROBE_TYPE_QUERY_UPSTREAM", "query-upstream"},
     {C_FLAGS (GST_PAD_PROBE_TYPE_PUSH), "GST_PAD_PROBE_TYPE_PUSH", "push"},
     {C_FLAGS (GST_PAD_PROBE_TYPE_PULL), "GST_PAD_PROBE_TYPE_PULL", "pull"},
+    {C_FLAGS (GST_PAD_PROBE_TYPE_BLOCKING), "GST_PAD_PROBE_TYPE_BLOCKING",
+        "blocking"},
+    {C_FLAGS (GST_PAD_PROBE_TYPE_DATA_DOWNSTREAM),
+        "GST_PAD_PROBE_TYPE_DATA_DOWNSTREAM", "data-downstream"},
+    {C_FLAGS (GST_PAD_PROBE_TYPE_DATA_UPSTREAM),
+        "GST_PAD_PROBE_TYPE_DATA_UPSTREAM", "data-upstream"},
+    {C_FLAGS (GST_PAD_PROBE_TYPE_DATA_BOTH), "GST_PAD_PROBE_TYPE_DATA_BOTH",
+        "data-both"},
+    {C_FLAGS (GST_PAD_PROBE_TYPE_BLOCK_DOWNSTREAM),
+        "GST_PAD_PROBE_TYPE_BLOCK_DOWNSTREAM", "block-downstream"},
+    {C_FLAGS (GST_PAD_PROBE_TYPE_BLOCK_UPSTREAM),
+        "GST_PAD_PROBE_TYPE_BLOCK_UPSTREAM", "block-upstream"},
+    {C_FLAGS (GST_PAD_PROBE_TYPE_EVENT_BOTH), "GST_PAD_PROBE_TYPE_EVENT_BOTH",
+        "event-both"},
+    {C_FLAGS (GST_PAD_PROBE_TYPE_QUERY_BOTH), "GST_PAD_PROBE_TYPE_QUERY_BOTH",
+        "query-both"},
+    {C_FLAGS (GST_PAD_PROBE_TYPE_ALL_BOTH), "GST_PAD_PROBE_TYPE_ALL_BOTH",
+        "all-both"},
+    {C_FLAGS (GST_PAD_PROBE_TYPE_SCHEDULING), "GST_PAD_PROBE_TYPE_SCHEDULING",
+        "scheduling"},
     {0, NULL, NULL}
   };
 
@@ -1524,16 +1544,16 @@ GType
 gst_segment_flags_get_type (void)
 {
   static gsize id = 0;
-  static const GEnumValue values[] = {
-    {C_ENUM (GST_SEGMENT_FLAG_NONE), "GST_SEGMENT_FLAG_NONE", "none"},
-    {C_ENUM (GST_SEGMENT_FLAG_RESET), "GST_SEGMENT_FLAG_RESET", "reset"},
-    {C_ENUM (GST_SEGMENT_FLAG_SKIP), "GST_SEGMENT_FLAG_SKIP", "skip"},
-    {C_ENUM (GST_SEGMENT_FLAG_SEGMENT), "GST_SEGMENT_FLAG_SEGMENT", "segment"},
+  static const GFlagsValue values[] = {
+    {C_FLAGS (GST_SEGMENT_FLAG_NONE), "GST_SEGMENT_FLAG_NONE", "none"},
+    {C_FLAGS (GST_SEGMENT_FLAG_RESET), "GST_SEGMENT_FLAG_RESET", "reset"},
+    {C_FLAGS (GST_SEGMENT_FLAG_SKIP), "GST_SEGMENT_FLAG_SKIP", "skip"},
+    {C_FLAGS (GST_SEGMENT_FLAG_SEGMENT), "GST_SEGMENT_FLAG_SEGMENT", "segment"},
     {0, NULL, NULL}
   };
 
   if (g_once_init_enter (&id)) {
-    GType tmp = g_enum_register_static ("GstSegmentFlags", values);
+    GType tmp = g_flags_register_static ("GstSegmentFlags", values);
     g_once_init_leave (&id, tmp);
   }
 
